@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2004, 2005 Joe Walnes.
- * Copyright (C) 2006, 2007, 2017 XStream Committers.
+ * Copyright (C) 2006, 2007, 2017, 2018 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
@@ -29,7 +29,7 @@ public class ISO8601DateConverter extends AbstractSingleValueConverter {
     private final ISO8601GregorianCalendarConverter converter = new ISO8601GregorianCalendarConverter();
 
     public boolean canConvert(Class type) {
-        return type.equals(Date.class) && converter.canConvert(GregorianCalendar.class);
+        return type == Date.class && converter.canConvert(GregorianCalendar.class);
     }
 
     public Object fromString(String str) {
