@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2005 Joe Walnes.
- * Copyright (C) 2006, 2007, 2011, 2013, 2014, 2015, 2016, 2017 XStream Committers.
+ * Copyright (C) 2006, 2007, 2011, 2013, 2014, 2015, 2016, 2017, 2018 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
@@ -35,7 +35,7 @@ public class ISO8601GregorianCalendarConverter extends AbstractSingleValueConver
 
     public ISO8601GregorianCalendarConverter() {
         SingleValueConverter svConverter = null;
-        final Class type = JVM.loadClassForName(JVM.is18()
+        final Class type = JVM.loadClassForName(JVM.isVersion(8)
             ? "com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter"
             : "com.thoughtworks.xstream.core.util.ISO8601JodaTimeConverter");
         try {
@@ -54,7 +54,7 @@ public class ISO8601GregorianCalendarConverter extends AbstractSingleValueConver
     }
 
     public boolean canConvert(final Class type) {
-        return converter != null && type.equals(GregorianCalendar.class);
+        return converter != null && type == GregorianCalendar.class;
     }
 
     public Object fromString(final String str) {
